pub fn verify<Mode: ExecutionMode>(
env: &Env<'_, '_, '_, '_, '_>,
txn: &Transaction,
) -> Result<(), ExecutionError>Expand description
Verifies two properties for input objects:
- That the
Pureinputs can be serialized to the type inferred and that the type is permissible- Can be relaxed under certain execution modes
- That any
Objectarguments are used validly. This means mutable references are taken only on mutable objects. And that the gas coin is only taken by value in transfer objects or withsui::coin::send_funds.